==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/sax/XMLName.h <==
// class gnu.xml.libxmlj.sax.XMLName

// class file dependencies
// @dep_class 271db5e77e174d4 gnu_xml_libxmlj_sax_XMLName
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_sax_XMLName_H_
#define _JC_gnu_xml_libxmlj_sax_XMLName_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_sax_GnomeXMLReader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_refs	_jc_gnu_xml_libxmlj_sax_XMLName$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$refs	_jc_gnu_xml_libxmlj_sax_XMLName$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$nonrefs	_jc_gnu_xml_libxmlj_sax_XMLName$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$object	_jc_gnu_xml_libxmlj_sax_XMLName$object;

typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$fields_struct	_jc_gnu_xml_libxmlj_sax_XMLName$fields_struct;
typedef const struct _jc_gnu_xml_libxmlj_sax_XMLName$vmethods	_jc_gnu_xml_libxmlj_sax_XMLName$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_XMLName$vtable	_jc_gnu_xml_libxmlj_sax_XMLName$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_XMLName$vtype	_jc_gnu_xml_libxmlj_sax_XMLName$vtype;

// Class fields structure
struct _jc_gnu_xml_libxmlj_sax_XMLName$fields_struct {
	struct _jc_java_lang_String$object	*XML__5fURI;
};
extern _jc_gnu_xml_libxmlj_sax_XMLName$fields_struct _jc_gnu_xml_libxmlj_sax_XMLName$class_fields;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_XMLName$method$_init$2b45fc809619d759(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_XMLName$object *, struct _jc_gnu_xml_libxmlj_sax_GnomeXMLReader$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_sax_XMLName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_XMLName$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_XMLName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_XMLName$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_XMLName$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_XMLName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_sax_XMLName$vmethods	gnu_xml_libxmlj_sax_XMLName;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_XMLName$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_XMLName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_refs {
	struct _jc_java_lang_String$object	*uri;
	struct _jc_java_lang_String$object	*localName;
	struct _jc_java_lang_String$object	*qName;
	struct _jc_java_lang_String$object	*prefix;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_XMLName$refs {
    _jc_gnu_xml_libxmlj_sax_XMLName$sub_refs	gnu_xml_libxmlj_sax_XMLName;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_XMLName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs	gnu_xml_libxmlj_sax_XMLName;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_XMLName$object {
	_jc_gnu_xml_libxmlj_sax_XMLName$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_XMLName$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_XMLName$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_XMLName$vtype _jc_gnu_xml_libxmlj_sax_XMLName$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_XMLName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_XMLName$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_XMLName_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/sax/XMLName.h <==
// class gnu.xml.libxmlj.sax.XMLName

// class file dependencies
// @dep_class 271db5e77e174d4 gnu_xml_libxmlj_sax_XMLName
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_sax_XMLName_H_
#define _JC_gnu_xml_libxmlj_sax_XMLName_H_

// Forward structure declarations
struct _jc_gnu_xml_libxmlj_sax_GnomeXMLReader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_refs	_jc_gnu_xml_libxmlj_sax_XMLName$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs	_jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$refs	_jc_gnu_xml_libxmlj_sax_XMLName$refs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$nonrefs	_jc_gnu_xml_libxmlj_sax_XMLName$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$object	_jc_gnu_xml_libxmlj_sax_XMLName$object;

typedef struct _jc_gnu_xml_libxmlj_sax_XMLName$fields_struct	_jc_gnu_xml_libxmlj_sax_XMLName$fields_struct;
typedef const struct _jc_gnu_xml_libxmlj_sax_XMLName$vmethods	_jc_gnu_xml_libxmlj_sax_XMLName$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_sax_XMLName$vtable	_jc_gnu_xml_libxmlj_sax_XMLName$vtable;
typedef const struct _jc_gnu_xml_libxmlj_sax_XMLName$vtype	_jc_gnu_xml_libxmlj_sax_XMLName$vtype;

// Class fields structure
struct _jc_gnu_xml_libxmlj_sax_XMLName$fields_struct {
	struct _jc_java_lang_String$object	*XML__5fURI;
};
extern _jc_gnu_xml_libxmlj_sax_XMLName$fields_struct _jc_gnu_xml_libxmlj_sax_XMLName$class_fields;

// Constructors
extern void _jc_gnu_xml_libxmlj_sax_XMLName$method$_init$2b45fc809619d759(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_XMLName$object *, struct _jc_gnu_xml_libxmlj_sax_GnomeXMLReader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_sax_XMLName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_XMLName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_sax_XMLName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_sax_XMLName$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_sax_XMLName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_sax_XMLName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_sax_XMLName$vmethods	gnu_xml_libxmlj_sax_XMLName;
};

// Vtype
struct _jc_gnu_xml_libxmlj_sax_XMLName$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_sax_XMLName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_refs {
	struct _jc_java_lang_String$object	*uri;
	struct _jc_java_lang_String$object	*localName;
	struct _jc_java_lang_String$object	*qName;
	struct _jc_java_lang_String$object	*prefix;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_XMLName$refs {
    _jc_gnu_xml_libxmlj_sax_XMLName$sub_refs	gnu_xml_libxmlj_sax_XMLName;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_sax_XMLName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_sax_XMLName$sub_nonrefs	gnu_xml_libxmlj_sax_XMLName;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_sax_XMLName$object {
	_jc_gnu_xml_libxmlj_sax_XMLName$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_sax_XMLName$vtype	*vtype;
	_jc_gnu_xml_libxmlj_sax_XMLName$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_sax_XMLName$vtype _jc_gnu_xml_libxmlj_sax_XMLName$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_sax_XMLName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_sax_XMLName$class_object;

#endif	/* _JC_gnu_xml_libxmlj_sax_XMLName_H_ */
